#
# spec file for package python-urlgrabber
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define modname urlgrabber
%define oldpython python
Name:           python-urlgrabber
Version:        4.1.0
Release:        150400.4.3.1
Summary:        A high-level cross-protocol url-grabber
License:        LGPL-2.1-only
Group:          Development/Libraries/Python
URL:            https://github.com/rpm-software-management/urlgrabber
Source:         https://github.com/rpm-software-management/%{modname}/releases/download/%{modname}-4-1-0/%{modname}-%{version}.tar.gz
# PATCH-FIX_UPSTREAM https://github.com/rpm-software-management/urlgrabber/pull/32
Patch0:         use-binary-mode-when-reopening-files.patch
# PATCH-FIX_UPSTREAM https://github.com/rpm-software-management/urlgrabber/pull/35
Patch1:         fix_find_proxy_logic_and_drop_six.patch

BuildRequires:  %{python_module pycurl}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pycurl
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
Conflicts:      %{oldpython}-urlgrabber
%endif
%python_subpackages

%description
A high-level cross-protocol url-grabber for python supporting HTTP, FTP
and file locations.  Features include keepalive, byte ranges,
throttling, authentication, proxies and more.

%prep
%setup -q -n urlgrabber-%{version}
# Remove with next release
sed -i "13d" urlgrabber/__init__.py # Remove wrong license header, fixes bnc#781323
%autopatch -p1

# Fix location of %%{_libexecdir}
sed -i 's!/usr/libexec!%{_libexecdir}!' urlgrabber/grabber.py
sed -i "s!libexec!$(echo %{_libexecdir}|cut -d/ -f 3)!" setup.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/urlgrabber
%python_clone -a %{buildroot}%{_libexecdir}/urlgrabber-ext-down
rm -rf %{buildroot}%{_datadir}/doc/urlgrabber-%{version} # Remove wrongly installed docs
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative urlgrabber
%{python_expand %{_sbindir}/update-alternatives --quiet --install %{_libexecdir}/urlgrabber-ext-down  urlgrabber-ext-down   %{_libexecdir}/urlgrabber-ext-down-%{$python_version}  %{$python_version_nodots}}

%postun
%python_uninstall_alternative urlgrabber

%files %{python_files}
%license LICENSE
%doc ChangeLog README TODO
%python_alternative %{_bindir}/urlgrabber
%python_alternative %{_libexecdir}/urlgrabber-ext-down
%{python_sitelib}/*

%changelog
* Thu Jun 16 2022 pablo.suarezhernandez@suse.com
- Fix wrong logic on find_proxy method causing proxy not being used
- Added:
  * fix_find_proxy_logic_and_drop_six.patch
* Wed Dec 22 2021 pablo.suarezhernandez@suse.com
- Add missing bugzilla references (bsc#1152514) (bsc#1146683)
* Tue Dec 21 2021 pablo.suarezhernandez@suse.com
- Use binary mode when reopening files
- Added:
  * use-binary-mode-when-reopening-files.patch
* Fri Oct  8 2021 mcepl@suse.com
- Make independent of the actual value of %%%%{_libexecdir} macro.
- Conflicts python-urlgrabber to avoid conflicts with older
  python2 version of the package (modern python2-urlgrabber is
  all right).
* Wed May 20 2020 pgajdos@suse.com
- urlgrabber-ext-down as an alternative
* Mon May 18 2020 pgajdos@suse.com
- %%python3_only -> %%python_alternative
- urlgrabber-ext-down is expected to reside under /usr/libexec
* Wed Oct  9 2019 tchvatal@suse.com
- Update to 4.1.0:
  * Fix confused license header to clarify licensing
  * Fix Python 3 compatibility with urlgrabber-ext-down
  * Support HTTP CONNECT with reget. BZ 1585596
  * Fix for usage of _levelNames from logging module
  * Fix issue when URLGRABBER_DEBUG is not an integer on Python 3
  * Revise setup.py to remove need for extra setup-time dependencies
  * setuptools: Update Development Status to Production/Stable
* Wed Feb 27 2019 tchvatal@suse.com
- Drop patch grabber_fix.diff that was never upstreamed. Should
  not be needed anymore
* Mon Feb 25 2019 mcepl@suse.com
- Update to the upstream version 4.0.0:
  * Port to Python 3 rocket
  * Add curl_obj option to grabber
  * Throw an obvious error message when urlgrabber-ext-down is
    missing when attempting to use external downloader
  * Use setuptools for setup.py instead of distutils
- Remove merged patches:
  * declare-dollar-sign-as-safe-in-urlquote.patch
  * python-urlgrabber-3.9.1-set-SSL_VERIFYHOST-correct.dif
  * python-urlgrabber-3.9.1-preserve-queryparams-in-urls.patch
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Tue May 29 2018 mcepl@suse.com
- Clean SPEC file
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu Feb 12 2015 mc@suse.de
- declare $ sign as a safe character in url paths to prevent
  escaping /$RCE/ which lead into problems with token auth
  (bnc#902416)
  * declare-dollar-sign-as-safe-in-urlquote.patch
  * python-urlgrabber-3.9.1-set-SSL_VERIFYHOST-correct.dif
- set curl option SSL_VERIFYHOST correct
* Tue Sep 16 2014 dmacvicar@suse.de
- Add python-urlgrabber-3.9.1-preserve-queryparams-in-urls.patch
  (bnc#896844)
* Wed Feb  6 2013 jmatejek@suse.com
- Add grabber_fix.diff: Fixed timeout and other errors breaking yum
  compatibility (bnc#793650)
* Mon Oct  1 2012 saschpe@suse.de
- Fixed wrong license header in urlgrabber/__init__.py (bnc#781323)
- Updated upstream URL, the project moved the baseurl.org (yum)
* Tue Sep 20 2011 saschpe@suse.de
- Update to version 3.9.1:
  * cleanup all the old urlgrabber urllib code that's not being used
  * delete sslfactory and keepalive fix up the unittests to match existing code
  * make sure the value we get back from the parse150 and other calls is
    converted to an int before we make it 'size' rhbug: #524705
- Spec file updates:
  * Removed authors from description
  * Dropped useless python-urlgrabber-2.9.9.patch
  * Dropped obsolete python-urlgrabber-3.1.0.patch (upstream changed)
  * Require python-pycurl
* Wed Aug 12 2009 matejcik@suse.cz
- build as noarch on newer distros
- switched filelist to --record-rpm
* Mon Aug 10 2009 coolo@novell.com
- sync factory and build service
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Tue May 12 2009 poeml@suse.de
- fix build on 11.1 onwards, where python must be in the
  buildrequires in addition to python-devel, because otherwise
  urllib2 appears to have no SSL support
* Fri Sep 26 2008 cthiel@suse.de
- add python to BuildRequires to fix build
* Tue Feb 19 2008 cthiel@suse.de
- fix url parsing error in grabber.py (bnc #362937)
* Mon Oct  2 2006 cthiel@suse.de
- fix build on older distributions
* Sun Oct  1 2006 cthiel@suse.de
- update to version 3.1.0
  * various fixes
* Thu Sep 21 2006 cthiel@suse.de
- fix build with python 2.5
* Fri Aug  4 2006 cthiel@suse.de
- update to version 2.9.10
  * Make keepalive, byteranges, etc. work with https.
  * Fixed a minor error reporting bug due to changes in python 2.4.
  * Catch read errors after the file has been opened.
- removed obsolete urlgrabber-read-error.patch
* Thu May 25 2006 cthiel@suse.de
- update to version 2.9.9
  * Added tests to make sure that the "quote" option works as advertised
  * Significant improvement to URL parsing.  Parsing is now broken out into
    a separate class (URLParser).  It will now (by default) guess whether a
    URL is already quoted, properly handle local files and URLs on windows,
    and display un-quoted versions of the filename in the progress meter.
  * Added a reget progress bar patch from Menno, and fixed the annoying next
    _IndexError bug.
- added urlgrabber-read-error.patch (from Fedora)
- removed python-urlgrabber-2.9.7-reget.patch (included upstream)
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 31 2005 dmueller@suse.de
- don't build as root
* Wed Oct 26 2005 cthiel@suse.de
- update to version 2.9.7
* Tue Sep 13 2005 cthiel@suse.de
- specfile cleanup
* Sun Aug 14 2005 cthiel@suse.de
- initial package (version 2.9.6)
